Enum UsernameError
pub enum UsernameError {
MissingSeparator,
NicknameCannotBeEmpty,
NicknameCannotStartWithDigit,
BadNicknameCharacter,
NicknameTooShort,
NicknameTooLong,
DiscriminatorCannotBeEmpty,
DiscriminatorCannotBeZero,
DiscriminatorCannotBeSingleDigit,
DiscriminatorCannotHaveLeadingZeros,
BadDiscriminatorCharacter,
DiscriminatorTooLarge,
}Variants
MissingSeparator
Username must contain a ‘.’
NicknameCannotBeEmpty
Name cannot be empty
NicknameCannotStartWithDigit
Name cannot start with a digit
BadNicknameCharacter
Nickname contains disallowed character
NicknameTooShort
Nickname is too short
NicknameTooLong
Nickname is too long
DiscriminatorCannotBeEmpty
Discriminator cannot be empty
DiscriminatorCannotBeZero
Discriminator cannot be zero
DiscriminatorCannotBeSingleDigit
Discriminator cannot be a single digit
DiscriminatorCannotHaveLeadingZeros
Discriminator cannot have leading zeros unless it would otherwise be a single digit
BadDiscriminatorCharacter
Discriminator must only be made up of digits
DiscriminatorTooLarge
Value is too large to be a username discriminator