IdentityKey

Struct IdentityKey 

pub struct IdentityKey { /* private fields */ }
A public key that represents the identity of a user.

Wrapper for PublicKey.

Implementations

Source

impl IdentityKey

pub fn new(public_key: PublicKey) -> IdentityKey

Initialize a public-facing identity from a public key.

pub fn public_key(&self) -> &PublicKey

Return the public key representing this identity.

pub fn into_public_key(self) -> PublicKey

Return the public key representing this identity

pub fn serialize(&self) -> Box<[u8]>

Return an owned byte slice which can be deserialized with Self::decode.

pub fn decode(value: &[u8]) -> Result<IdentityKey, SignalProtocolError>

Deserialize a public identity from a byte slice.

pub fn verify_alternate_identity( &self, other: &IdentityKey, signature: &[u8], ) -> Result<bool, SignalProtocolError>

Given a trusted identity self, verify that other represents an alternate identity for this user.

signature must be calculated from IdentityKeyPair::sign_alternate_identity.

pub fn is_same_account( &self, self_protocol_address: &ProtocolAddress, other_key: &IdentityKey, other_protocol_address: &ProtocolAddress, ) -> bool

Do two (identity key, protocol address) pairs map to the same account

This function will always return false if the names in the protocol addresses aren’t valid service IDs.