pub struct IdentityKey { /* private fields */ }Expand description
A public key that represents the identity of a user.
Wrapper for PublicKey.
Implementations
Sourceimpl IdentityKey
impl IdentityKey
Sourcepub fn new(public_key: PublicKey) -> IdentityKey
pub fn new(public_key: PublicKey) -> IdentityKey
Initialize a public-facing identity from a public key.
Sourcepub fn public_key(&self) -> &PublicKey
pub fn public_key(&self) -> &PublicKey
Return the public key representing this identity.
Sourcepub fn serialize(&self) -> Box<[u8]>
pub fn serialize(&self) -> Box<[u8]>
Return an owned byte slice which can be deserialized with Self::decode.
Sourcepub fn decode(value: &[u8]) -> Result<IdentityKey, SignalProtocolError>
pub fn decode(value: &[u8]) -> Result<IdentityKey, SignalProtocolError>
Deserialize a public identity from a byte slice.
Sourcepub fn verify_alternate_identity(
&self,
other: &IdentityKey,
signature: &[u8],
) -> Result<bool, SignalProtocolError>
pub fn verify_alternate_identity( &self, other: &IdentityKey, signature: &[u8], ) -> Result<bool, SignalProtocolError>
Given a trusted identity self, verify that other represents an alternate identity for
this user.
signature must be calculated from IdentityKeyPair::sign_alternate_identity.